@@ -361,12 +361,22 @@ class RawRegisterClient(EventEmitter):
 
         self.bus.run(send)
 
-    def float_value(self, scale: int = 1) -> Union[float, None]:
+    def value(self) -> Optional[Any]:
+        """Extracts the value of the first field."""
         values = self.values()
         if values is None:
             return None
         else:
-            return float(values[0]) * scale  # type: ignore
+            return values[0]
+
+    def bool_value(self) -> Optional[bool]:
+        """Extracts the value of the first field as a boolean."""
+        value = self.value()
+        return bool(value) if not value is None else None
+
+    def float_value(self, scale: int = 1) -> Optional[float]:
+        value = self.value()
+        return float(value) * scale if not value is None else None
 
     def _query(self):
         pkt = JDPacket(cmd=JD_GET(self.code))
